# Streamlit SeqViz
A Streamlit library for [seqviz](https://www.npmjs.com/package/seqviz)

|white theme | dark theme |
|------------|------------|
|![Streamlit sample white theme](imgs/white_screen.png)|![Streamlit sample dark theme](imgs/black_screen.png)|

## Todo list
* [x] show component
* [x] support params name, seq, annotations,style, highlights, enzymes
* [ ] support the rest of parameters
* [ ] on selection return values on streamlit
* [ ] adaptive size
* [ ] deploy on pypi

## Develop
This is the guide for developers.

### Frontend
```
cd streamlit_seqviz/frontend
npm install

npm run dev
# http://localhost:5173/
```

### Streamlit
```
python3 -m venv venv
source venv/bin/activate.fish
pip install streamlit

streamlit run streamlit_seqviz/__init__.py
# http://localhost:8501/
```

## Tesing builded lib
```
python3 -m venv venv
# Set from streamlit_seqviz/__init__.py _RELEASE=True
pip install -e .
streamlit run test.py
```

## Deploy pipy
* prepare your ~/.pypirc file

```
[pypi]
repository=https://pypi.python.org/pypi
username = __token__
password = <token>
```

* build frontend

```
cd streamlit_seqviz/frontend
rm -rf dist
npm run build
```

* build backend

```
pip install twine

# Set from streamlit_seqviz/__init__.py _RELEASE=True
rm -rf dist

python setup.py sdist
twine check dist/*
```

* upload

```
twine upload dist/*
```

## References
* [python](https://www.python.org/): programming language for develop the tool
* [HTML](https://www.w3schools.com/html/): markup language for the output file generated by the tool
* [JavaScript](https://www.w3schools.com/js/): programming language used into the HTML for logic implementation 
* [vite](https://vitejs.dev/): js builder
* [streamlit](https://streamlit.io/): python library to make quick and dirty UI
* [vite vanilla js streamlit component](https://dev.to/aisone/streamlit-custom-components-vite-vanilla-js-40hl): how to create vanilla js plugin for streamlit
* [How to use seq-viz](https://medium.com/lattice-automation/visualize-your-dna-sequences-with-seqviz-b1d945eb9684): a library for draw dna sequences
* [How to write setup.py and deploy on pypi](https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56): important for deploy the code as python lib
* [Gitlab CI/CD for python registry](https://docs.gitlab.com/ee/user/packages/pypi_repository/): how to setup pipeline to gitlab python registry
